pandas.Series.typecheck
=======================

.. method:: pandas.Series.typecheck(*args, **kwargs) -> pandas.Series:

    An attached version of :func:`typecheck` that allows users to omit the
    ``data`` argument.

    This method is defined for every type.
